;; Generated package description from tramp-nspawn.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "tramp-nspawn" "1.0.2" "Tramp integration for systemd-nspawn containers" '((emacs "23")) :commit "a2da5b6b25be7191755678651bdade2f9af5c617" :authors '(("Brian Cully" . "bjc@kublai.com")) :maintainer '("Brian Cully" . "bjc@kublai.com") :keywords '("tramp" "nspawn" "machinectl" "systemd" "systemd-nspawn") :url "https://git.spork.org/tramp-nspawn.git")
